Index: pkg/analyzer/lib/src/summary/idl.dart |
diff --git a/pkg/analyzer/lib/src/summary/idl.dart b/pkg/analyzer/lib/src/summary/idl.dart |
index 505ade8855078f11d43b869fa4e25538db8d00fb..60a0552f6e6048c4abd55fdd5bb052e9390fa8f6 100644 |
--- a/pkg/analyzer/lib/src/summary/idl.dart |
+++ b/pkg/analyzer/lib/src/summary/idl.dart |
@@ -714,12 +714,32 @@ abstract class PackageIndex extends base.SummaryClass { |
/** |
* Each item of this list corresponds to a unique referenced element. It is |
- * the offset of the element name relative to the beginning of the file. The |
- * list is sorted in ascending order, so that the client can quickly check |
- * whether an element is referenced in this [PackageIndex]. |
+ * the identifier of the class member element name, or `null` if the element is |
+ * a top-level element. The list is sorted in ascending order, so that the |
+ * client can quickly check whether an element is referenced in this |
+ * [PackageIndex]. |
+ */ |
+ @Id(7) |
+ List<int> get elementNameClassMemberIds; |
+ |
+ /** |
+ * Each item of this list corresponds to a unique referenced element. It is |
+ * the identifier of the named parameter name, or `null` if the element is not |
+ * a named parameter. The list is sorted in ascending order, so that the |
+ * client can quickly check whether an element is referenced in this |
+ * [PackageIndex]. |
+ */ |
+ @Id(8) |
+ List<int> get elementNameParameterIds; |
+ |
+ /** |
+ * Each item of this list corresponds to a unique referenced element. It is |
+ * the identifier of the top-level element name, or `null` if the element is |
+ * the unit. The list is sorted in ascending order, so that the client can |
+ * quickly check whether an element is referenced in this [PackageIndex]. |
*/ |
@Id(1) |
- List<int> get elementOffsets; |
+ List<int> get elementNameUnitMemberIds; |
/** |
* Each item of this list corresponds to a unique referenced element. It is |